pub enum DependencyType {
Crate(Crate),
Repo(Repo),
Path(String),
}Expand description
Represents the different types of dependencies
Variants
Crate(Crate)
This is a crate retrieved from a crate registry like crates.io using it’s name and it’s semver version number
Repo(Repo)
This is a crate retrieved from a git repository
Path(String)
This is a crate retrieved from a filesystem path