pub enum RepoType {
Rev(String),
Tag(String),
Branch(String),
}Expand description
Sets a specific commit of a repository to use
Variants
Rev(String)
Sets the specific commit to the given hash
Tag(String)
Sets the specific commit to the commit pointed to by the given tag
Branch(String)
Sets the specific commit to the commit pointed to by the given branch name