Dependency

Struct Dependency 

pub struct Dependency { /* private fields */ }
Represents a single dependency

Implementations

Source

impl Dependency

pub fn repo(label: &str, repo: &str) -> Dependency

Constructs a Depedency that points to a git repo

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::repo("foo", "https://github.com/foo/bar");
// translates to:
// [dependencies]
// foo = { git = "https://github.com/foo/bar" }
pub fn version(label: &str, version: &str) -> Dependency

Constructs a Depedency that specifies a semver version

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::version("foo", "0.1.0");
// translates to:
// [dependencies]
// foo = "0.1.0"
pub fn path(label: &str, path: &str) -> Dependency

Constructs a Depedency that points to a path

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::path("foo", "/path/to/foo");
// translates to:
// [dependencies]
// foo = { path = "/path/to/foo" }
pub fn rev(label: &str, repo: &str, rev: &str) -> Dependency

Constructs a Depedency that points to a specific revision of a repository

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::rev("foo", "https://github.com/foo/bar", "0a14cbe3928");
// translates to:
// [dependencies]
// foo = { git = "https://github.com/foo/bar", rev = "0a14cbe3928" }
pub fn tag(label: &str, repo: &str, tag: &str) -> Dependency

Constructs a Depedency that points to a specific tag of a repository

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::tag("foo", "https://github.com/foo/bar", "v1.0.0");
// translates to:
// [dependencies]
// foo = { git = "https://github.com/foo/bar", tag = "v1.0.0" }
pub fn branch(label: &str, repo: &str, branch: &str) -> Dependency

Constructs a Depedency that points to a specific branch of a repository

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::branch("foo", "https://github.com/foo/bar", "some-branch");
// translates to:
// [dependencies]
// foo = { git = "https://github.com/foo/bar", branch = "some-branch" }
pub fn build(&self) -> Self

If the builder pattern has been used to construct this Dependency, this takes ownership

pub fn optional(&mut self, optional: bool) -> &mut Self

Mark this dependency as “optional = true”

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::version("foo", "0.1.0")
                     .optional(true)
                     .build();
// translates to:
// [dependencies]
// foo = { version = "0.1.0", optional = true }
pub fn default_features(&mut self, default_features: bool) -> &mut Self

Specify whether this dependency is using the default features or not

Example
extern crate cargo_toml_builder;
use cargo_toml_builder::prelude::*;
let dep = Dependency::version("foo", "0.1.0")
                     .default_features(false)
                     .build();
// translates to:
// [dependencies]
// foo = { version = "0.1.0", default-features = false }