pub struct LibTarget { /* private fields */ }Expand description
Represents a [lib] table
Implementations
Sourceimpl LibTarget
impl LibTarget
Sourcepub fn new() -> LibTargetBuilder
pub fn new() -> LibTargetBuilder
Constructs a new builder for a lib target
Sourcepub fn path(&self) -> Option<&String>
pub fn path(&self) -> Option<&String>
Returns the value of the path to the root for this lib target
Sourcepub fn doctest(&self) -> Option<bool>
pub fn doctest(&self) -> Option<bool>
Returns the value of the doctest flag for this lib target
Sourcepub fn proc_macro(&self) -> Option<bool>
pub fn proc_macro(&self) -> Option<bool>
Returns the value of the proc-macro flag for this lib target
Sourcepub fn harness(&self) -> Option<bool>
pub fn harness(&self) -> Option<bool>
Returns the value of the harness flag for this lib target
Sourcepub fn crate_type(&self) -> Option<CrateType>
pub fn crate_type(&self) -> Option<CrateType>
Returns the value of the crate-type for this lib target