NonLibTarget

Struct NonLibTarget 

pub struct NonLibTarget { /* private fields */ }
Represents [[bench]], [[bin]], [[example]], and [[test]] tables

Implementations

Source

impl NonLibTarget

pub fn new() -> NonLibTargetBuilder

Constructs a builder for a non-lib target (bin, example, bench, test)

pub fn name(&self) -> Option<&String>

Returns the value of the name of this target

pub fn path(&self) -> Option<&String>

Returns the value of the path to the root for this target

pub fn test(&self) -> Option<bool>

Returns the value of the test flag for this target

pub fn doctest(&self) -> Option<bool>

Returns the value of the doctest flag for this target

pub fn bench(&self) -> Option<bool>

Returns the value of the bench flag for this target

pub fn doc(&self) -> Option<bool>

Returns the value of the doc flag for this target

pub fn plugin(&self) -> Option<bool>

Returns the value of the plugin flag for this target

pub fn proc_macro(&self) -> Option<bool>

Returns the value of the proc-macro flag for this target

pub fn harness(&self) -> Option<bool>

Returns the value of the harness flag for this target

pub fn required_features(&self) -> Option<&Vec<String>>

Returns the value of the required-features value for this target