pub struct PatchSet { /* private fields */ }Expand description
Represents a patchset for a Cargo.toml
Implementations
Sourceimpl PatchSet
impl PatchSet
Sourcepub fn patch<D: Into<Dependency>>(&mut self, patch: D) -> &mut Self
pub fn patch<D: Into<Dependency>>(&mut self, patch: D) -> &mut Self
Adds a single patch to this builder
Will not affect any other patches that have been added
Sourcepub fn patches(&mut self, patches: &[Dependency]) -> &mut Self
pub fn patches(&mut self, patches: &[Dependency]) -> &mut Self
Adds a set of patches to this builder
WILL replace any existing patches that have been added to this builder