pub struct Workspace { /* private fields */ }Expand description
Represents the [workspace] section of a Cargo.toml file
Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn member(&mut self, member: &str) -> &mut Self
pub fn member(&mut self, member: &str) -> &mut Self
Adds a single member to this builder
Will not affect any existing members that have been added
Sourcepub fn members(&mut self, members: &[String]) -> &mut Self
pub fn members(&mut self, members: &[String]) -> &mut Self
Adds a set of members to this builder
WILL replace any existing members that have been added
Sourcepub fn exclude(&mut self, exclude: &str) -> &mut Self
pub fn exclude(&mut self, exclude: &str) -> &mut Self
Adds an exclude to this builder
Will not affect any other excludes that have been added