LibTarget

Struct LibTarget 

pub struct LibTarget { /* private fields */ }
Represents a [lib] table

Implementations

Source

impl LibTarget

pub fn new() -> LibTargetBuilder

Constructs a new builder for a lib target

pub fn name(&self) -> Option<&String>

Returns the value of the name of this lib target

pub fn path(&self) -> Option<&String>

Returns the value of the path to the root for this lib target

pub fn test(&self) -> Option<bool>

Returns the value of the test flag for this lib target

pub fn doctest(&self) -> Option<bool>

Returns the value of the doctest flag for this lib target

pub fn bench(&self) -> Option<bool>

Returns the value of the bench flag for this lib target

pub fn doc(&self) -> Option<bool>

Returns the value of the doc flag for this lib target

pub fn plugin(&self) -> Option<bool>

Returns the value of the plugin flag for this lib target

pub fn proc_macro(&self) -> Option<bool>

Returns the value of the proc-macro flag for this lib target

pub fn harness(&self) -> Option<bool>

Returns the value of the harness flag for this lib target

pub fn crate_type(&self) -> Option<CrateType>

Returns the value of the crate-type for this lib target